"""Page widgets for multi-page GUI."""

from .base_page import BasePage
from .connection_page import ConnectionPage
from .window_page import WindowPage
from .area_page import AreaPage
from .chat_page import ChatPage

__all__ = [
    "BasePage",
    "ConnectionPage",
    "WindowPage",
    "AreaPage",
    "ChatPage",
]
